[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

hyatt hyatt at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 07:02:17 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit 0394b747baacac3cd43580c1caa12d49c7067edc
Author: hyatt <hyatt at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Mon Nov 18 04:59:41 2002 +0000

    	More refinements to immediate painting code.  Still doesn't
    	fix the scrollbar problem though. :(
    
            * khtml/html/html_documentimpl.cpp:
            (HTMLDocumentImpl::close):
            * khtml/khtmlview.cpp:
            (KHTMLView::init):
            (KHTMLView::timerEvent):
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@2724 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/ChangeLog-2002-12-03 b/WebCore/ChangeLog-2002-12-03
index d8c7b79..9f2d690 100644
--- a/WebCore/ChangeLog-2002-12-03
+++ b/WebCore/ChangeLog-2002-12-03
@@ -1,5 +1,16 @@
 2002-11-17  David Hyatt  <hyatt at apple.com>
 
+	More refinements to immediate painting code.  Still doesn't
+	fix the scrollbar problem though. :(
+	
+        * khtml/html/html_documentimpl.cpp:
+        (HTMLDocumentImpl::close):
+        * khtml/khtmlview.cpp:
+        (KHTMLView::init):
+        (KHTMLView::timerEvent):
+
+2002-11-17  David Hyatt  <hyatt at apple.com>
+
 	Make immediate repainting of the root element more robust.
 	
         * khtml/html/html_documentimpl.cpp:
diff --git a/WebCore/ChangeLog-2003-10-25 b/WebCore/ChangeLog-2003-10-25
index d8c7b79..9f2d690 100644
--- a/WebCore/ChangeLog-2003-10-25
+++ b/WebCore/ChangeLog-2003-10-25
@@ -1,5 +1,16 @@
 2002-11-17  David Hyatt  <hyatt at apple.com>
 
+	More refinements to immediate painting code.  Still doesn't
+	fix the scrollbar problem though. :(
+	
+        * khtml/html/html_documentimpl.cpp:
+        (HTMLDocumentImpl::close):
+        * khtml/khtmlview.cpp:
+        (KHTMLView::init):
+        (KHTMLView::timerEvent):
+
+2002-11-17  David Hyatt  <hyatt at apple.com>
+
 	Make immediate repainting of the root element more robust.
 	
         * khtml/html/html_documentimpl.cpp:
diff --git a/WebCore/ChangeLog-2005-08-23 b/WebCore/ChangeLog-2005-08-23
index d8c7b79..9f2d690 100644
--- a/WebCore/ChangeLog-2005-08-23
+++ b/WebCore/ChangeLog-2005-08-23
@@ -1,5 +1,16 @@
 2002-11-17  David Hyatt  <hyatt at apple.com>
 
+	More refinements to immediate painting code.  Still doesn't
+	fix the scrollbar problem though. :(
+	
+        * khtml/html/html_documentimpl.cpp:
+        (HTMLDocumentImpl::close):
+        * khtml/khtmlview.cpp:
+        (KHTMLView::init):
+        (KHTMLView::timerEvent):
+
+2002-11-17  David Hyatt  <hyatt at apple.com>
+
 	Make immediate repainting of the root element more robust.
 	
         * khtml/html/html_documentimpl.cpp:
diff --git a/WebCore/khtml/khtmlview.cpp b/WebCore/khtml/khtmlview.cpp
index 6ddfccf..5ac043e 100644
--- a/WebCore/khtml/khtmlview.cpp
+++ b/WebCore/khtml/khtmlview.cpp
@@ -265,6 +265,7 @@ void KHTMLView::init()
     _height = 0;
 
     setAcceptDrops(true);
+    
     resizeContents(visibleWidth(), visibleHeight());
 }
 
@@ -1464,16 +1465,16 @@ void KHTMLView::timerEvent ( QTimerEvent *e )
     }
 
     if( m_part->xmlDocImpl() ) {
-	DOM::DocumentImpl *document = m_part->xmlDocImpl();
-	khtml::RenderRoot* root = static_cast<khtml::RenderRoot *>(document->renderer());
-	resizeContents(root->docWidth(), root->docHeight());
-	if ( !root->layouted() ) {
-	    killTimer(d->repaintTimerId);
-	    d->repaintTimerId = 0;
-	    //qDebug("not layouted, delaying repaint");
-	    scheduleRelayout();
-	    return;
-	}
+        DOM::DocumentImpl *document = m_part->xmlDocImpl();
+        khtml::RenderRoot* root = static_cast<khtml::RenderRoot *>(document->renderer());
+        if ( !root->layouted() ) {
+            killTimer(d->repaintTimerId);
+            d->repaintTimerId = 0;
+            //qDebug("not layouted, delaying repaint");
+            scheduleRelayout();
+            return;
+        }
+        resizeContents(root->docWidth(), root->docHeight());
     }
     setStaticBackground(d->useSlowRepaints);
 

diff --git a/WebCore/khtml/html/html_documentimpl.cpp b/WebCore/khtml/html/html_documentimpl.cpp
index 18018e5..e182bf0 100644
--- a/WebCore/khtml/html/html_documentimpl.cpp
+++ b/WebCore/khtml/html/html_documentimpl.cpp
@@ -324,9 +324,14 @@ void HTMLDocumentImpl::close()
     if (body() && doload) {
         updateRendering();
         
-        // Always do a full and immediate repaint after loading.
-        if (renderer())
+        // Always do a full and immediate layout/repaint after loading.
+        if (renderer()) {
+            if (!renderer()->layouted()) {
+                renderer()->layout();
+                view()->unscheduleRelayout();
+            }
             renderer()->repaint(true);
+        }
     }
 }
 
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list